package App::Nopaste::Service::Husk;
use strict;
use warnings;
use base 'App::Nopaste::Service';

sub uri { "http://paste.husk.org" }

=head1 NAME

App::Nopaste::Service::Husk - http://paste.husk.org/

=cut

1;

